Skip to main contentCrate sing_util
Source - TokenStreamWrapper
- Wraps the proc_macro2 Tokenstream type,
so it can be serialized and deserialized.
- TraitProfile
- Represents a trait as Function names associated with tokenstreams.
- DeduplicatedFunctionProfile
- Represents the state of a function name,
with it either being only present once or existing multiple times.
- TraitCallMessage
- Needs to be implemented by all structs that are used to represent
function calls that are sent through a sing I/O stream